Interface: PluginOptionsByType | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: PluginOptionsByType<TType>

## # Type parameters

Name | Type
--- | ---
`TType` | extends `ChartType`

## # Properties

### # decimation

• decimation: `DecimationOptions`

#### # Defined in

index.esm.d.ts:2837
(opens new window)

### # filler

• filler: `FillerOptions`

#### # Defined in

index.esm.d.ts:2838
(opens new window)

### # legend

• legend: `LegendOptions`<`TType`>

#### # Defined in

index.esm.d.ts:2839
(opens new window)

### # subtitle

• subtitle: `TitleOptions`

#### # Defined in

index.esm.d.ts:2840
(opens new window)

### # title

• title: `TitleOptions`

#### # Defined in

index.esm.d.ts:2841
(opens new window)

### # tooltip

• tooltip: `TooltipOptions`<`TType`>

#### # Defined in

index.esm.d.ts:2842
(opens new window)